@@ -1,7 +1,9 @@
+from ._detector import SDetector
 from ._gaussian_detectors import LoGDetector, DoGDetector, DoHDetector
 from ._seg_detector import SSegDetector
 
-__all__ = ['LoGDetector',
+__all__ = ['SDetector',
+           'LoGDetector',
            'DoGDetector',
            'DoHDetector',
            'SSegDetector']
