@@ -1,5 +1,7 @@
+from ._feature import SFeature
 from ._length import LengthFeature, DisplacementFeature, DistanceFeature
 
-__all__ = ['LengthFeature',
+__all__ = ['SFeature',
+           'LengthFeature',
            'DisplacementFeature',
            'DistanceFeature']
