@@ -25,7 +25,7 @@ class StIO(STrackIO):
         self.indent = None
 
     def is_compatible(self):
-        if self.file_path.endswith('.st.json'):
+        if self.file_path.endswith('.json'):
             return True
         return False
 
@@ -51,6 +51,8 @@ class StIO(STrackIO):
 
         if 'scale' in json_data:
             self.stracks.scale = tuple(json_data['scale'])
+            if len(self.stracks.scale) < self.stracks.data.shape[0]-1:
+                self.stracks.scale = list(np.ones(self.stracks.data.shape[1]-1))
 
     def write(self, tracks):
         self.stracks = tracks
@@ -60,11 +62,17 @@ class StIO(STrackIO):
         json_data['properties'] = dict()
         if self.stracks.properties is not None:
             for key in self.stracks.properties:
-                json_data['properties'][key] = self.stracks.properties[key].tolist()
+                if isinstance(self.stracks.properties[key], list):
+                    json_data['properties'][key] = self.stracks.properties[key]
+                else:
+                    json_data['properties'][key] = self.stracks.properties[key].tolist()
 
         json_data['graph'] = self.stracks.graph
         json_data['features'] = self.stracks.features
-        json_data['scale'] = list(self.stracks.scale)
+        if self.stracks.scale is not None:
+            json_data['scale'] = list(self.stracks.scale)
+        else:
+            json_data['scale'] = []
 
         # write the data to file
         with open(self.file_path, 'w') as outfile:
